@@ -2,6 +2,11 @@
 //!
 //! This implementation hides the transport layer, statefulness and the protocol version to the [fetch delegate][fetch::Delegate],
 //! the actual client implementation.
+//! ## Feature Flags
+#![cfg_attr(
+    feature = "document-features",
+    cfg_attr(doc, doc = ::document_features::document_features!())
+)]
 #![deny(unsafe_code)]
 #![deny(rust_2018_idioms, missing_docs)]
 
